@@ -1,9 +1,12 @@
 /*
  * print-photo-info.c - Flickcurl example code to get information about a photo
  *
- * This is example code and not complete because the API Key, Shared
- * Secret and Auth Token are not configured.  The flickcurl utility
- * in utils/flickcurl.c contains code that fully uses the API.
+ * This is example code and not complete because the OAuth client
+ * key, secret and the token and token secret are not configured.
+ *
+ * The flickcurl utility in utils/flickcurl.c contains code that
+ * fully uses the API and read/writes configuration from a file
+ * using flickcurl_config_var_handler()
  *
  * This file is in the Public Domain
  *
@@ -26,17 +29,25 @@ int main(int argc, char *argv[]) {
   int i;
 
   flickcurl_init(); /* optional static initialising of resources */
-  fc=flickcurl_new();
+  fc = flickcurl_new();
 
-  /* Set configuration, or more likely read from a config file */
-  flickcurl_set_api_key(fc, "...");
-  flickcurl_set_shared_secret(fc, "...");
-  flickcurl_set_auth_token(fc, "...");
+  /* Set configuration explicitly: ... */
+  flickcurl_set_oauth_client_key(fc, "...");
+  flickcurl_set_oauth_client_secret(fc, "...");
+  flickcurl_set_oauth_token(fc, "...");
+  flickcurl_set_oauth_token_secret(fc, "...");
 
-  photo=flickcurl_photos_getInfo(fc, "123456789"); /* photo ID */
+  /* or could read from an INI config file like this: */
+  /*
+  flickcurl_config_read_ini(fc, "/home/user/.flickcurl.conf", "flickr",
+                            fc, flickcurl_config_var_handler);
+  */  
 
-  for(field_type=0; field_type <= PHOTO_FIELD_LAST; field_type++) {
-    flickcurl_field_value_type datatype=photo->fields[field_type].type;
+
+  photo = flickcurl_photos_getInfo(fc, "123456789"); /* photo ID */
+
+  for(field_type = 0; field_type <= PHOTO_FIELD_LAST; field_type++) {
+    flickcurl_field_value_type datatype = photo->fields[field_type].type;
     
     if(datatype != VALUE_TYPE_NONE)
       fprintf(stderr, "field %s (%d) with %s value: '%s' / %d\n", 
@@ -46,7 +57,7 @@ int main(int argc, char *argv[]) {
               photo->fields[field_type].integer);
   }
 
-  for(i=0; i < photo->tags_count; i++) {
+  for(i = 0; i < photo->tags_count; i++) {
     flickcurl_tag* tag=photo->tags[i];
     fprintf(stderr,
             "%d) %s tag: id %s author ID %s name %s raw '%s' cooked '%s' count %d\n",
