@@ -2,7 +2,7 @@
  *
  * collection.c - Flickcurl collection functions
  *
- * Copyright (C) 2009, David Beckett http://www.dajobe.org/
+ * Copyright (C) 2009-2012, David Beckett http://www.dajobe.org/
  * 
  * This file is licensed under the following three licenses as alternatives:
  *   1. GNU Lesser General Public License (LGPL) V2.1 or any newer version
@@ -181,7 +181,7 @@ flickcurl_build_collections(flickcurl* fc, xmlXPathContextPtr xpathCtx,
   int i;
   
   xpathExpr_len = strlen((const char*)xpathExpr);
-  strncpy((char*)full_xpath, (const char*)xpathExpr, xpathExpr_len+1);
+  memcpy(full_xpath, xpathExpr, xpathExpr_len + 1);
   
   xpathObj = xmlXPathEvalExpression(xpathExpr, xpathCtx);
   if(!xpathObj) {
@@ -319,8 +319,11 @@ flickcurl_build_collections(flickcurl* fc, xmlXPathContextPtr xpathCtx,
           break;
       }
       
-      if(fc->failed)
+      if(fc->failed) {
+        if(collection)
+          flickcurl_free_collection(collection);
         goto tidy;
+      }
     }
 
 #if FLICKCURL_DEBUG > 1
@@ -344,8 +347,11 @@ flickcurl_build_collections(flickcurl* fc, xmlXPathContextPtr xpathCtx,
   if(xpathObj)
     xmlXPathFreeObject(xpathObj);
   
-  if(fc->failed)
+  if(fc->failed) {
+    if(collections)
+      flickcurl_free_collections(collections);
     collections = NULL;
+  }
 
   return collections;
 }
