@@ -63,9 +63,9 @@
 
 #include <libxml/xmlsave.h>
 
-const char* const flickcurl_short_copyright_string = "Copyright 2007-2012 David Beckett.";
+const char* const flickcurl_short_copyright_string = "Copyright 2007-2013 David Beckett.";
 
-const char* const flickcurl_copyright_string = "Copyright (C) 2007-2012 David Beckett - http://www.dajobe.org/";
+const char* const flickcurl_copyright_string = "Copyright (C) 2007-2013 David Beckett - http://www.dajobe.org/";
 
 const char* const flickcurl_license_string = "LGPL 2.1 or newer, GPL 2 or newer, Apache 2.0 or newer.\nSee http://librdf.org/flickcurl/ for full terms.";
 
@@ -73,7 +73,7 @@ const char* const flickcurl_home_url_string = "http://librdf.org/flickcurl/";
 const char* const flickcurl_version_string = VERSION;
 
 
-const char* const flickcurl_flickr_service_uri =  "http://www.flickr.com/services/rest/?";
+const char* const flickcurl_flickr_service_uri =  "http://www.flickr.com/services/rest/";
 const char* const flickcurl_flickr_upload_service_uri =  "http://api.flickr.com/services/upload/";
 const char* const flickcurl_flickr_replace_service_uri =  "http://api.flickr.com/services/replace/";
 const char* const flickcurl_flickr_oauth_request_token_uri =  "http://www.flickr.com/services/oauth/request_token";
@@ -167,7 +167,7 @@ flickcurl_write_callback(void *ptr, size_t size, size_t nmemb,
     } else
       rc = xmlParseChunk(fc->xc, (const char*)ptr, len, 0);
 
-#if FLICKCURL_DEBUG > 2
+#if FLICKCURL_DEBUG > 1
     fprintf(stderr, "Got >>%s<< (%d bytes)\n", (const char*)ptr, len);
 #endif
 
@@ -183,6 +183,22 @@ flickcurl_write_callback(void *ptr, size_t size, size_t nmemb,
 }
 
 
+#if FLICKCURL_DEBUG > 1
+static int
+flickcurl_debug_callback(CURL *handle, curl_infotype type,
+                         char *data, size_t size, void *userptr)
+{
+  if(type == CURLINFO_TEXT) {
+    fprintf(stderr, "INFO %s", data);
+  } else {
+    char dir = (type == CURLINFO_HEADER_IN || type == CURLINFO_DATA_IN || type == CURLINFO_SSL_DATA_IN) ? '<' : '>';
+    fprintf(stderr, "%c %s", dir, data);
+  }
+  return 0;
+}
+#endif
+
+
 /**
  * flickcurl_new_with_handle:
  * @curl_handle: CURL* handle
@@ -260,8 +276,10 @@ flickcurl_new_with_handle(void* curl_handle)
   /* Make it follow Location: headers */
   curl_easy_setopt(fc->curl_handle, CURLOPT_FOLLOWLOCATION, 1);
 
-#if FLICKCURL_DEBUG > 2
+#if FLICKCURL_DEBUG > 1
   curl_easy_setopt(fc->curl_handle, CURLOPT_VERBOSE, (void*)1);
+  curl_easy_setopt(fc->curl_handle, CURLOPT_DEBUGFUNCTION,
+                   flickcurl_debug_callback);
 #endif
 
   curl_easy_setopt(fc->curl_handle, CURLOPT_ERRORBUFFER, fc->error_buffer);
@@ -769,10 +787,24 @@ flickcurl_set_request_delay(flickcurl *fc, long delay_msec)
  * INTERNAL: initialise parameter array
  */
 void
-flickcurl_init_params(flickcurl *fc)
+flickcurl_init_params(flickcurl *fc, int is_write)
 {
   fc->count = 0;
   fc->parameters[fc->count][0] = NULL;
+
+  /* Default is read only */
+  fc->is_write = is_write;
+
+  /* Default to no data */
+  if(fc->data) {
+    if(fc->data_is_xml)
+      xmlFree(fc->data);
+    fc->data = NULL;
+    fc->data_length = 0;
+    fc->data_is_xml = 0;
+  }
+  if(is_write)
+    flickcurl_set_data(fc, (void*)"", 0);
 }
 
 
@@ -799,7 +831,7 @@ flickcurl_end_params(flickcurl *fc)
 
 static int
 flickcurl_prepare_common(flickcurl *fc, 
-                         const char* url,
+                         const char* service_uri,
                          const char* method,
                          const char* upload_field,
                          const char* upload_value,
@@ -809,12 +841,12 @@ flickcurl_prepare_common(flickcurl *fc,
 
   if(fc->api_key && fc->secret)
     /* Call with legacy Flickr auth */
-    rc = flickcurl_legacy_prepare_common(fc, url, method,
+    rc = flickcurl_legacy_prepare_common(fc, service_uri, method,
                                          upload_field, upload_value,
                                          parameters_in_url, need_auth);
   else if(fc->od.token && fc->od.token_secret)
     /* Call with OAuth */
-    rc = flickcurl_oauth_prepare_common(fc, url, method,
+    rc = flickcurl_oauth_prepare_common(fc, service_uri, method,
                                         upload_field, upload_value,
                                         parameters_in_url, need_auth);
   else
@@ -853,7 +885,8 @@ flickcurl_prepare(flickcurl *fc, const char* method)
                                   fc->service_uri,
                                   method,
                                   NULL, NULL,
-                                  1, 1);
+                                  /* parameters_in_url */ 1,
+                                  /* need_auth */ 1);
 }
 
 
@@ -866,7 +899,8 @@ flickcurl_prepare_upload(flickcurl *fc,
                                   url,
                                   NULL,
                                   upload_field, upload_value,
-                                  0, 1);
+                                  /* parameters_in_url */ 0,
+                                  /* need_auth */ 1);
 }
 
 
@@ -1232,9 +1266,6 @@ flickcurl_invoke_common(flickcurl *fc, char** content_p, size_t* size_p,
     curl_easy_setopt(fc->curl_handle, CURLOPT_POST, 1);
     curl_easy_setopt(fc->curl_handle, CURLOPT_POSTFIELDS, fc->data);
     curl_easy_setopt(fc->curl_handle, CURLOPT_POSTFIELDSIZE, fc->data_length);
-    /* Replace default POST content type 'application/x-www-form-urlencoded' */
-    slist = curl_slist_append(slist, (const char*)"Content-Type: application/xml");
-    /* curl_easy_setopt(fc->curl_handle, CURLOPT_CUSTOMREQUEST, fc->verb); */
   } else if(fc->is_write) {
     /* write with no data: POST */
     /* CURLOPT_NOBODY = 0 sets http request to HEAD - do it first to override */
@@ -1254,6 +1285,11 @@ flickcurl_invoke_common(flickcurl *fc, char** content_p, size_t* size_p,
   curl_easy_setopt(fc->curl_handle, CURLOPT_WRITEHEADER, fc);
 
 
+#ifdef FLICKCURL_DEBUG
+  fprintf(stderr, "Preparing CURL with URI '%s' and method %s\n", 
+          fc->uri, ((fc->is_write || fc->upload_field) ? "POST" : "GET"));
+#endif
+  
   if(fc->upload_field) {
     struct curl_httppost* post = NULL;
     struct curl_httppost* last = NULL;
@@ -1261,12 +1297,20 @@ flickcurl_invoke_common(flickcurl *fc, char** content_p, size_t* size_p,
     
     /* Main parameters */
     for(i = 0; fc->param_fields[i]; i++) {
+#ifdef FLICKCURL_DEBUG
+      fprintf(stderr, "  form param %2d) %-23s: '%s'\n",
+              i, fc->param_fields[i], fc->param_values[i]);
+#endif
       curl_formadd(&post, &last, CURLFORM_PTRNAME, fc->param_fields[i],
                    CURLFORM_PTRCONTENTS, fc->param_values[i],
                    CURLFORM_END);
     }
     
     /* Upload parameter */
+#ifdef FLICKCURL_DEBUG
+    fprintf(stderr, "  Upload form parameter %s: <File '%s'>\n",
+            fc->upload_field, fc->upload_value);
+#endif
     curl_formadd(&post, &last, CURLFORM_PTRNAME, fc->upload_field,
                  CURLFORM_FILE, fc->upload_value, CURLFORM_END);
 
@@ -1278,10 +1322,9 @@ flickcurl_invoke_common(flickcurl *fc, char** content_p, size_t* size_p,
     fc->curl_setopt_handler(fc->curl_handle, fc->curl_setopt_handler_data);
 
 #ifdef FLICKCURL_DEBUG
-  fprintf(stderr, "Resolving URI '%s' with method %s\n", 
-          fc->uri, ((fc->is_write || fc->upload_field) ? "POST" : "GET"));
+  fprintf(stderr, "Invoking CURL to resolve the URL\n");
 #endif
-  
+
   if(curl_easy_perform(fc->curl_handle)) {
     /* failed */
     fc->failed = 1;
@@ -1821,7 +1864,7 @@ flickcurl_call_get_one_string_field(flickcurl* fc,
   xmlDocPtr doc = NULL;
   xmlXPathContextPtr xpathCtx = NULL; 
 
-  flickcurl_init_params(fc);  
+  flickcurl_init_params(fc, 0);
   if(key && value) {
     flickcurl_add_param(fc, key, value);
   }
