@@ -2,7 +2,7 @@
  *
  * config.c - INI configuration file handling
  *
- * Copyright (C) 2007-2010, David Beckett http://www.dajobe.org/
+ * Copyright (C) 2007-2012, David Beckett http://www.dajobe.org/
  * 
  * This file is licensed under the following three licenses as alternatives:
  *   1. GNU Lesser General Public License (LGPL) V2.1 or any newer version
@@ -244,7 +244,14 @@ flickcurl_config_var_handler(void* userdata,
     flickcurl_set_shared_secret(fc, value);
   else if(!strcmp(key, "auth_token"))
     flickcurl_set_auth_token(fc, value);
-
+  else if(!strcmp(key, "oauth_client_key"))
+    flickcurl_set_oauth_client_key(fc, value);
+  else if(!strcmp(key, "oauth_client_secret"))
+    flickcurl_set_oauth_client_secret(fc, value);
+  else if(!strcmp(key, "oauth_token"))
+    flickcurl_set_oauth_token(fc, value);
+  else if(!strcmp(key, "oauth_token_secret"))
+    flickcurl_set_oauth_token_secret(fc, value);
 }
 
 
@@ -280,21 +287,46 @@ flickcurl_config_write_ini(flickcurl *fc,
   fputc('[', fh);
   fputs(section, fh);
   fputc(']', fh);
-  s = flickcurl_get_auth_token(fc);
+
+  s = flickcurl_get_oauth_token(fc);
   if(s) {
-    fputs("\nauth_token=", fh);
-    fputs(s, fh);
-  }
-  s = flickcurl_get_api_key(fc);
-  if(s) {
-    fputs("\napi_key=", fh);
-    fputs(s, fh);
-  }
-  s = flickcurl_get_shared_secret(fc);
-  if(s) {
-    fputs("\nsecret=", fh);
+    /* OAuth token and secret */
+    fputs("\noauth_token=", fh);
     fputs(s, fh);
+    s = flickcurl_get_oauth_token_secret(fc);
+    if(s) {
+      fputs("\noauth_token_secret=", fh);
+      fputs(s, fh);
+    }
+    s = flickcurl_get_oauth_client_key(fc);
+    if(s) {
+      fputs("\noauth_client_key=", fh);
+      fputs(s, fh);
+    }
+    s = flickcurl_get_oauth_client_secret(fc);
+    if(s) {
+      fputs("\noauth_client_secret=", fh);
+      fputs(s, fh);
+    }
+  } else {
+    /* Legacy Flickr auth */
+    s = flickcurl_get_auth_token(fc);
+    if(s) {
+      fputs("\noauth_token=", fh);
+      fputs(s, fh);
+    }
+    s = flickcurl_get_shared_secret(fc);
+    if(s) {
+      fputs("\noauth_secret=", fh);
+      fputs(s, fh);
+    }
+    s = flickcurl_get_api_key(fc);
+    if(s) {
+      fputs("\napi_key=", fh);
+      fputs(s, fh);
+    }
   }
+  
   fputs("\n", fh);
 
   fclose(fh);
