@@ -119,11 +119,12 @@ flickcurl_build_contacts(flickcurl* fc,
     contact_object = (flickcurl_contact*)calloc(sizeof(flickcurl_contact), 1);
     
     for(attr = node->properties; attr; attr = attr->next) {
+      size_t attr_len = strlen((const char*)attr->children->content);
       const char *attr_name = (const char*)attr->name;
       char *attr_value;
       
-      attr_value = (char*)malloc(strlen((const char*)attr->children->content)+1);
-      strcpy(attr_value, (const char*)attr->children->content);
+      attr_value = (char*)malloc(attr_len + 1);
+      memcpy(attr_value, attr->children->content, attr_len + 1);
       
       if(!strcmp(attr_name, "nsid"))
         contact_object->nsid = attr_value;
