@@ -279,7 +279,7 @@ flickcurl_sort_args(flickcurl *fc)
  */
 int
 flickcurl_oauth_prepare_common(flickcurl *fc,
-                               const char* url,
+                               const char* service_uri,
                                const char* method,
                                const char* upload_field,
                                const char* upload_value,
@@ -289,17 +289,16 @@ flickcurl_oauth_prepare_common(flickcurl *fc,
   int i;
   char *signature_string = NULL;
   size_t* values_len = NULL;
-  unsigned int fc_uri_len = 0;
-  unsigned int full_uri_len = 0;
+  unsigned int fc_uri_len = 0; /* length of URI path */
+  unsigned int full_uri_len = 0; /* includes ? and paramters */
   char* nonce = NULL;
   int free_nonce = 0;
   char* timestamp = NULL;
   int rc = 0;
-  int need_to_add_query = 0;
   int is_oauth_method = 0;
   char *p;
 
-  if(!url)
+  if(!service_uri)
     return 1;
   
   /* If one is given, both are required */
@@ -312,16 +311,6 @@ flickcurl_oauth_prepare_common(flickcurl *fc,
     free(fc->error_msg);
     fc->error_msg = NULL;
   }
-  /* Default to read */
-  fc->is_write = 0;
-  /* Default to no data */
-  if(fc->data) {
-    if(fc->data_is_xml)
-      xmlFree(fc->data);
-    fc->data = NULL;
-    fc->data_length = 0;
-    fc->data_is_xml = 0;
-  }
   if(fc->param_fields) {
     for(i = 0; fc->param_fields[i]; i++) {
       free(fc->param_fields[i]);
@@ -416,11 +405,11 @@ flickcurl_oauth_prepare_common(flickcurl *fc,
     flickcurl_sort_args(fc);
 
 
-  fc_uri_len = strlen(url);
+  fc_uri_len = strlen(service_uri);
   full_uri_len = fc_uri_len;
 
-  if(url[fc_uri_len - 1] != '?')
-    need_to_add_query++;
+  if(parameters_in_url)
+    full_uri_len++;
   
   /* Save away the parameters and calculate the value lengths */
   for(i = 0; fc->parameters[i][0]; i++) {
@@ -494,7 +483,7 @@ flickcurl_oauth_prepare_common(flickcurl *fc,
 
     buf_len = http_method_len;
     buf_len += 1; /* & */
-    buf_len += (3 * strlen(url));
+    buf_len += (3 * strlen(service_uri));
     buf_len += 1; /* & */
     buf_len += param_buf_len * 3;
 
@@ -506,7 +495,7 @@ flickcurl_oauth_prepare_common(flickcurl *fc,
 
     *p++ = '&';
 
-    escaped_value = curl_escape(url, 0);
+    escaped_value = curl_escape(service_uri, 0);
     escaped_value_len = strlen(escaped_value);
     memcpy(p, escaped_value, escaped_value_len);
     p += escaped_value_len;
@@ -581,15 +570,15 @@ flickcurl_oauth_prepare_common(flickcurl *fc,
     fc->uri = (char*)malloc(full_uri_len + 1);
     fc->uri_len = full_uri_len;
   }
-  memcpy(fc->uri, url, fc_uri_len);
+  /* fc_uri_len is strlen(service_uri) at this point */
+  memcpy(fc->uri, service_uri, fc_uri_len);
 
   p = fc->uri + fc_uri_len;
   *p = '\0';
 
-  if(need_to_add_query)
+  if(parameters_in_url) {
     *p++ = '?';
 
-  if(parameters_in_url) {
     for(i = 0; fc->parameters[i][0]; i++) {
       char *value = (char*)fc->parameters[i][1];
       size_t len;
@@ -617,9 +606,13 @@ flickcurl_oauth_prepare_common(flickcurl *fc,
 
 #ifdef FLICKCURL_DEBUG
   fprintf(stderr, "Request URI:\n  %s\n", fc->uri);
-
-  FLICKCURL_ASSERT((strlen(fc->uri) == fc_uri_len),
-                   "Final URI does not match expected length");
+  do {
+    size_t m_len = strlen(fc->uri);
+    if(m_len > full_uri_len) {
+      fprintf(stderr, "%s:%d: (%s) assertion failed: Final URI len %zu is larger than buffer %zu\n", __FILE__, __LINE__, __func__, m_len, (size_t)full_uri_len);
+      FLICKCURL_ASSERT_DIE
+    }
+  } while(0);
 #endif
 
   tidy:
