@@ -2,7 +2,7 @@
  *
  * person.c - Flickr person support calls
  *
- * Copyright (C) 2007-2008, David Beckett http://www.dajobe.org/
+ * Copyright (C) 2007-2012, David Beckett http://www.dajobe.org/
  * 
  * This file is licensed under the following three licenses as alternatives:
  *   1. GNU Lesser General Public License (LGPL) V2.1 or any newer version
@@ -244,7 +244,7 @@ flickcurl_build_persons(flickcurl* fc, xmlXPathContextPtr xpathCtx,
   int i;
   
   xpathExpr_len = strlen((const char*)xpathExpr);
-  strncpy((char*)full_xpath, (const char*)xpathExpr, xpathExpr_len+1);
+  memcpy(full_xpath, xpathExpr, xpathExpr_len + 1);
   
   xpathObj = xmlXPathEvalExpression(xpathExpr, xpathCtx);
   if(!xpathObj) {
@@ -261,7 +261,7 @@ flickcurl_build_persons(flickcurl* fc, xmlXPathContextPtr xpathCtx,
 
   for(i = 0, person_count = 0; i < nodes_count; i++) {
     xmlNodePtr node = nodes->nodeTab[i];
-    flickcurl_person* person;
+    flickcurl_person* person = NULL;
     int expri;
     xmlXPathContextPtr xpathNodeCtx = NULL;
     
@@ -358,10 +358,22 @@ flickcurl_build_persons(flickcurl* fc, xmlXPathContextPtr xpathCtx,
 #endif
       
       if(fc->failed)
-        goto tidy;
+        break;
+    } /* end for person fields */
+
+    if(fc->failed) {
+      if(person)
+        flickcurl_free_person(person);
+    } else {
+      persons[person_count++] = person;
     }
+    
+    if(xpathNodeCtx)
+      xmlXPathFreeContext(xpathNodeCtx);
+
+    if(fc->failed)
+      goto tidy;
 
-    persons[person_count++] = person;
   } /* for persons */
   
   if(person_count_p)
@@ -371,8 +383,11 @@ flickcurl_build_persons(flickcurl* fc, xmlXPathContextPtr xpathCtx,
   if(xpathObj)
     xmlXPathFreeObject(xpathObj);
   
-  if(fc->failed)
+  if(fc->failed) {
+    if(persons)
+      flickcurl_free_persons(persons);
     persons = NULL;
+  }
 
   return persons;
 }
