@@ -2,7 +2,7 @@
  *
  * photo.c - Flickcurl photo functions
  *
- * Copyright (C) 2007-2010, David Beckett http://www.dajobe.org/
+ * Copyright (C) 2007-2012, David Beckett http://www.dajobe.org/
  * 
  * This file is licensed under the following three licenses as alternatives:
  *   1. GNU Lesser General Public License (LGPL) V2.1 or any newer version
@@ -203,8 +203,8 @@ flickcurl_photo_as_source_uri(flickcurl_photo *photo, const char c)
             photo->fields[PHOTO_FIELD_secret].string);
   }
   len = strlen(buf);
-  result = (char*)malloc(len+1);
-  strcpy(result, buf);
+  result = (char*)malloc(len + 1);
+  memcpy(result, buf, len + 1);
   return result;
 }
 
@@ -229,8 +229,8 @@ flickcurl_photo_as_page_uri(flickcurl_photo *photo)
           photo->fields[PHOTO_FIELD_owner_nsid].string, photo->id);
 
   len = strlen(buf);
-  result = (char*)malloc(len+1);
-  strncpy(result, buf, len+1);
+  result = (char*)malloc(len + 1);
+  memcpy(result, buf, len + 1);
   return result;
 }
 
@@ -286,7 +286,7 @@ flickcurl_photo_id_as_short_uri(char *photo_id)
     return NULL;
   
   r = result;
-  strncpy(result, short_uri_prefix, SHORT_URI_PREFIX_LEN);
+  memcpy(result, short_uri_prefix, SHORT_URI_PREFIX_LEN);
   r += SHORT_URI_PREFIX_LEN;
   /* now copy it backwards into new result string */
   while(p != buf)
@@ -405,18 +405,21 @@ flickcurl_user_icon_uri(int farm, int server, char *nsid)
 {
   char buf[1024];
   char *result;
-  size_t len;
   
-  if(server && farm && nsid)
-  /* http://farm{icon-farm}.static.flickr.com/{icon-server}/buddyicons/{nsid}.jpg */
+  if(server && farm && nsid) {
+    size_t len;
+    /* http://farm{icon-farm}.static.flickr.com/{icon-server}/buddyicons/{nsid}.jpg */
     sprintf(buf, "http://farm%d.static.flickr.com/%d/buddicons/%s.jpg", 
-            farm, server, nsid);
-  else
-    strcpy(buf, "http://www.flickr.com/images/buddyicon.jpg");
+            farm, server, nsid); 
+    len = strlen(buf);
+    result = (char*)malloc(len + 1);
+    memcpy(result, buf, len + 1);
+  } else {
+    #define MAGIC_LEN 42
+    result = (char*)malloc(MAGIC_LEN + 1);
+    memcpy(result, "http://www.flickr.com/images/buddyicon.jpg", MAGIC_LEN + 1);
+  }
 
-  len = strlen(buf);
-  result = (char*)malloc(len+1);
-  strncpy(result, buf, len+1);
   return result;
 }
 
@@ -968,7 +971,7 @@ flickcurl_build_photos(flickcurl* fc, xmlXPathContextPtr xpathCtx,
   int i;
   
   xpathExpr_len = strlen((const char*)xpathExpr);
-  strncpy((char*)full_xpath, (const char*)xpathExpr, xpathExpr_len+1);
+  memcpy(full_xpath, xpathExpr, xpathExpr_len + 1);
   
   xpathObj = xmlXPathEvalExpression(xpathExpr, xpathCtx);
   if(!xpathObj) {
@@ -1060,8 +1063,8 @@ flickcurl_build_photos(flickcurl* fc, xmlXPathContextPtr xpathCtx,
                     string_value, (long)unix_time, new_value);
 #endif
             free(string_value);
-            string_value= new_value;
-            int_value= (int)unix_time;
+            string_value = new_value;
+            int_value = (int)unix_time;
             datatype = VALUE_TYPE_DATETIME;
           } else
             /* failed to convert, make it a string */
@@ -1072,6 +1075,7 @@ flickcurl_build_photos(flickcurl* fc, xmlXPathContextPtr xpathCtx,
         case VALUE_TYPE_BOOLEAN:
           if(!*string_value && datatype == VALUE_TYPE_BOOLEAN) {
             /* skip setting field with a boolean value '' */
+            free(string_value);
             special = 1;
             break;
           }
@@ -1084,6 +1088,7 @@ flickcurl_build_photos(flickcurl* fc, xmlXPathContextPtr xpathCtx,
           photo->tags = flickcurl_build_tags_from_string(fc, photo,
                                                          (const char*)string_value,
                                                          &photo->tags_count);
+          free(string_value);
           special = 1;
           break;
 
@@ -1100,6 +1105,7 @@ flickcurl_build_photos(flickcurl* fc, xmlXPathContextPtr xpathCtx,
           abort();
       }
 
+      /* If special, do not store here */
       if(special)
         continue;
 
@@ -1134,8 +1140,9 @@ flickcurl_build_photos(flickcurl* fc, xmlXPathContextPtr xpathCtx,
                                          &photo->notes_count);
 
     if(!photo->media_type) {
-      photo->media_type = (char*)malloc(6);
-      strncpy(photo->media_type, "photo", 6);
+#define PHOTO_STR_LEN 5
+      photo->media_type = (char*)malloc(PHOTO_STR_LEN + 1);
+      memcpy(photo->media_type, "photo", PHOTO_STR_LEN + 1);
     }
 
     if(xpathNodeCtx)
@@ -1150,8 +1157,11 @@ flickcurl_build_photos(flickcurl* fc, xmlXPathContextPtr xpathCtx,
   tidy:
   if(xpathObj)
     xmlXPathFreeObject(xpathObj);
-  if(fc->failed)
+  if(fc->failed) {
+    if(photos)
+      flickcurl_free_photos(photos);
     photos = NULL;
+  }
 
   return photos;
 }
@@ -1215,6 +1225,9 @@ flickcurl_invoke_photos_list(flickcurl* fc, const xmlChar* xpathExpr,
   size_t format_len;
 
   photos_list = flickcurl_new_photos_list(fc);
+  if(!photos_list)
+    return NULL;
+
   if(format) {
     nformat = format;
     format_len = strlen(format);
@@ -1327,7 +1340,7 @@ flickcurl_invoke_photos_list(flickcurl* fc, const xmlChar* xpathExpr,
     fc->failed = 1;
     goto tidy;
   }
-  memcpy(photos_list->format, nformat, format_len+1);
+  memcpy(photos_list->format, nformat, format_len + 1);
 
   tidy:
   if(xpathNodeCtx)
