@@ -61,7 +61,7 @@ flickcurl_photosets_addPhoto(flickcurl* fc, const char* photoset_id,
   xmlDocPtr doc = NULL;
   int result = 1;
   
-  flickcurl_init_params(fc);
+  flickcurl_init_params(fc, 1);
 
   if(!photoset_id || !photo_id)
     return 1;
@@ -74,9 +74,6 @@ flickcurl_photosets_addPhoto(flickcurl* fc, const char* photoset_id,
   if(flickcurl_prepare(fc, "flickr.photosets.addPhoto"))
     goto tidy;
 
-  flickcurl_set_write(fc, 1);
-  flickcurl_set_data(fc, (void*)"", 0);
-
   doc = flickcurl_invoke(fc);
   if(!doc)
     goto tidy;
@@ -115,7 +112,7 @@ flickcurl_photosets_create(flickcurl* fc, const char* title,
   xmlXPathContextPtr xpathCtx = NULL; 
   char* photoset_id = NULL;
   
-  flickcurl_init_params(fc);
+  flickcurl_init_params(fc, 1);
 
   if(!title || !primary_photo_id)
     return NULL;
@@ -131,9 +128,6 @@ flickcurl_photosets_create(flickcurl* fc, const char* title,
   if(flickcurl_prepare(fc, "flickr.photosets.create"))
     goto tidy;
 
-  flickcurl_set_write(fc, 1);
-  flickcurl_set_data(fc, (void*)"", 0);
-
   doc = flickcurl_invoke(fc);
   if(!doc)
     goto tidy;
@@ -179,7 +173,7 @@ flickcurl_photosets_delete(flickcurl* fc, const char* photoset_id)
 {
   xmlDocPtr doc = NULL;
   
-  flickcurl_init_params(fc);
+  flickcurl_init_params(fc, 1);
 
   if(!photoset_id)
     return 1;
@@ -191,9 +185,6 @@ flickcurl_photosets_delete(flickcurl* fc, const char* photoset_id)
   if(flickcurl_prepare(fc, "flickr.photosets.delete"))
     goto tidy;
 
-  flickcurl_set_write(fc, 1);
-  flickcurl_set_data(fc, (void*)"", 0);
-
   doc = flickcurl_invoke(fc);
   if(!doc)
     goto tidy;
@@ -224,7 +215,7 @@ flickcurl_photosets_editMeta(flickcurl* fc, const char* photoset_id,
   xmlDocPtr doc = NULL;
   int result = 1;
   
-  flickcurl_init_params(fc);
+  flickcurl_init_params(fc, 1);
 
   if(!photoset_id || !title)
     return 1;
@@ -240,9 +231,6 @@ flickcurl_photosets_editMeta(flickcurl* fc, const char* photoset_id,
   if(flickcurl_prepare(fc, "flickr.photosets.editMeta"))
     goto tidy;
 
-  flickcurl_set_write(fc, 1);
-  flickcurl_set_data(fc, (void*)"", 0);
-
   doc = flickcurl_invoke(fc);
   if(!doc)
     goto tidy;
@@ -281,7 +269,7 @@ flickcurl_photosets_editPhotos(flickcurl* fc, const char* photoset_id,
   int result = 1;
   char* photo_ids = NULL;
   
-  flickcurl_init_params(fc);
+  flickcurl_init_params(fc, 1);
 
   if(!photoset_id || !primary_photo_id || !photo_ids_array)
     return 1;
@@ -296,9 +284,6 @@ flickcurl_photosets_editPhotos(flickcurl* fc, const char* photoset_id,
   if(flickcurl_prepare(fc, "flickr.photosets.editPhotos"))
     goto tidy;
 
-  flickcurl_set_write(fc, 1);
-  flickcurl_set_data(fc, (void*)"", 0);
-
   doc = flickcurl_invoke(fc);
   if(!doc)
     goto tidy;
@@ -335,7 +320,7 @@ flickcurl_photosets_getContext(flickcurl* fc, const char* photo_id,
   xmlDocPtr doc = NULL;
   flickcurl_context** contexts = NULL;
   
-  flickcurl_init_params(fc);
+  flickcurl_init_params(fc, 0);
 
   if(!photo_id || !photoset_id)
     return NULL;
@@ -381,7 +366,7 @@ flickcurl_photosets_getInfo(flickcurl* fc, const char* photoset_id)
   xmlXPathContextPtr xpathCtx = NULL; 
   flickcurl_photoset* photoset = NULL;
   
-  flickcurl_init_params(fc);
+  flickcurl_init_params(fc, 0);
 
   if(!photoset_id)
     return NULL;
@@ -436,7 +421,7 @@ flickcurl_photosets_getList(flickcurl* fc, const char* user_id)
   xmlXPathContextPtr xpathCtx = NULL; 
   flickcurl_photoset** photoset_list = NULL;
 
-  flickcurl_init_params(fc);
+  flickcurl_init_params(fc, 0);
 
   if(user_id) {
     flickcurl_add_param(fc, "user_id", user_id);
@@ -500,7 +485,7 @@ flickcurl_photosets_getPhotos_params(flickcurl* fc, const char* photoset_id,
   char privacy_filter_str[2];
   const char* format = NULL;
   
-  flickcurl_init_params(fc);
+  flickcurl_init_params(fc, 0);
 
   if(!photoset_id)
     return NULL;
@@ -600,7 +585,7 @@ flickcurl_photosets_orderSets(flickcurl* fc, const char** photoset_ids_array)
   int result = 1;
   char* photoset_ids;
   
-  flickcurl_init_params(fc);
+  flickcurl_init_params(fc, 0);
 
   if(!photoset_ids_array)
     return 1;
@@ -648,7 +633,7 @@ flickcurl_photosets_removePhoto(flickcurl* fc, const char* photoset_id,
   xmlDocPtr doc = NULL;
   int result = 1;
   
-  flickcurl_init_params(fc);
+  flickcurl_init_params(fc, 1);
 
   if(!photoset_id || !photo_id)
     return 1;
@@ -661,9 +646,6 @@ flickcurl_photosets_removePhoto(flickcurl* fc, const char* photoset_id,
   if(flickcurl_prepare(fc, "flickr.photosets.removePhoto"))
     goto tidy;
 
-  flickcurl_set_write(fc, 1);
-  flickcurl_set_data(fc, (void*)"", 0);
-
   doc = flickcurl_invoke(fc);
   if(!doc)
     goto tidy;
@@ -698,7 +680,7 @@ flickcurl_photosets_removePhotos(flickcurl* fc, const char* photoset_id,
   int result = 1;
   char* photo_ids = NULL;
   
-  flickcurl_init_params(fc);
+  flickcurl_init_params(fc, 1);
 
   if(!photoset_id || !photo_ids_array)
     return 1;
@@ -712,9 +694,6 @@ flickcurl_photosets_removePhotos(flickcurl* fc, const char* photoset_id,
   if(flickcurl_prepare(fc, "flickr.photosets.removePhotos"))
     goto tidy;
 
-  flickcurl_set_write(fc, 1);
-  flickcurl_set_data(fc, (void*)"", 0);
-
   doc = flickcurl_invoke(fc);
   if(!doc)
     goto tidy;
@@ -752,7 +731,7 @@ flickcurl_photosets_reorderPhotos(flickcurl* fc, const char* photoset_id,
   int result = 1;
   char* photo_ids = NULL;
   
-  flickcurl_init_params(fc);
+  flickcurl_init_params(fc, 0);
 
   if(!photoset_id || !photo_ids_array)
     return 1;
@@ -802,7 +781,7 @@ flickcurl_photosets_setPrimaryPhoto(flickcurl* fc, const char* photoset_id,
   xmlDocPtr doc = NULL;
   int result = 1;
   
-  flickcurl_init_params(fc);
+  flickcurl_init_params(fc, 1);
 
   if(!photoset_id || !photo_id)
     return 1;
@@ -815,9 +794,6 @@ flickcurl_photosets_setPrimaryPhoto(flickcurl* fc, const char* photoset_id,
   if(flickcurl_prepare(fc, "flickr.photosets.setPrimaryPhoto"))
     goto tidy;
 
-  flickcurl_set_write(fc, 1);
-  flickcurl_set_data(fc, (void*)"", 0);
-
   doc = flickcurl_invoke(fc);
   if(!doc)
     goto tidy;
