@@ -559,8 +559,11 @@ flickcurl_build_places(flickcurl* fc, xmlXPathContextPtr xpathCtx,
   if(xpathObj)
     xmlXPathFreeObject(xpathObj);
   
-  if(fc->failed)
+  if(fc->failed) {
+    if(places)
+      flickcurl_free_places(places);
     places = NULL;
+  }
 
   return places;
 }
@@ -667,7 +670,8 @@ flickcurl_build_place_types(flickcurl* fc, xmlXPathContextPtr xpathCtx,
   nodes = xpathObj->nodesetval;
   /* This is a max size - it can include nodes that are CDATA */
   nodes_count = xmlXPathNodeSetGetLength(nodes);
-  place_types = (flickcurl_place_type_info**)calloc(sizeof(flickcurl_place_type*), nodes_count + 1);
+  place_types = (flickcurl_place_type_info**)calloc(nodes_count + 1,
+                                                    sizeof(flickcurl_place_type_info*));
   
   for(i = 0, place_type_count = 0; i < nodes_count; i++) {
     xmlNodePtr node = nodes->nodeTab[i];
@@ -681,27 +685,30 @@ flickcurl_build_place_types(flickcurl* fc, xmlXPathContextPtr xpathCtx,
       break;
     }
     
-    pt = (flickcurl_place_type_info*)calloc(sizeof(flickcurl_place_type), 1);
+    pt = (flickcurl_place_type_info*)calloc(1, sizeof(*pt));
     
     for(attr = node->properties; attr; attr = attr->next) {
+      size_t attr_len = strlen((const char*)attr->children->content);
       const char *attr_name = (const char*)attr->name;
       char *attr_value;
 
-      attr_value = (char*)malloc(strlen((const char*)attr->children->content)+1);
-      strcpy(attr_value, (const char*)attr->children->content);
+      attr_value = (char*)malloc(attr_len + 1);
+      memcpy(attr_value, attr->children->content, attr_len + 1);
       
       if(!strcmp(attr_name, "id")) {
         pt->id = atoi(attr_value);
         free(attr_value);
         pt->type = flickcurl_place_id_to_type(pt->id);
-      }
+      } else
+        free(attr_value);
     }
 
     /* Walk children nodes for name text */
     for(chnode = node->children; chnode; chnode = chnode->next) {
       if(chnode->type == XML_TEXT_NODE) {
-        pt->name = (char*)malloc(strlen((const char*)chnode->content)+1);
-        strcpy(pt->name, (const char*)chnode->content);
+        size_t len = strlen((const char*)chnode->content);
+        pt->name = (char*)malloc(len + 1);
+        memcpy(pt->name, chnode->content, len + 1);
       }
     }
 
